@@ -394,7 +394,12 @@ def upload_stats_main(
     res_df = []
 
     mini_summaries, sample_ids = stats(
-        s3paths, sample_names, sample_ids, results_folder, cellranger, hash_tags,
+        s3paths=s3paths,
+        sample_names=sample_names,
+        sample_ids=sample_ids,
+        results_folder=results_folder,
+        cellranger=cellranger,
+        hash_tags=hash_tags,
     )
 
     for data in mini_summaries:
